import { scaleLinear, axisLeft, axisBottom, extent } from 'd3';
import {
  xAxis,
  yAxis,
  xAxisLabel,
  yAxisLabel,
} from '@curran/axis-labels';

export const viz = (
  svg,
  {
    data,
    xValue,
    xAxisLabelText,
    xAxisLabelOffset,
    yValue,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    innerRectFill,
    circleRadius,
    circleOpacity,
  },
) => {
  const xScale = scaleLinear().domain(extent(data, xValue)).range([marginLeft, width - marginRight]);
  const yScale = scaleLinear().domain(extent(data, yValue)).range([height - marginBottom, marginTop]);

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  svg.selectAll('rect')
    .data([null])
    .join('rect')
    .attr('x', marginLeft)
    .attr('y', marginTop)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', innerRectFill);

  // Updating Axes
  svg.selectAll('.x-axis').data([null])
    .join('g')
      .attr('class', 'x-axis')
      .attr('transform', `translate(0,${height - marginBottom})`)
      .call(axisBottom(xScale).ticks(width / 70).tickFormat(d => `${d}`));

  svg.selectAll('.y-axis').data([null])
    .join('g')
      .attr('class', 'y-axis')
      .attr('transform', `translate(${marginLeft},0)`)
      .call(axisLeft(yScale).ticks(height / 40).tickFormat(d => `${d}`));

  // Axis Labels (might be redundant, ensure to integrate or adjust with existing label logic)
  xAxisLabel(svg, {
    xAxisLabelText,
    width,
    height,
    marginBottom,
    xAxisLabelOffset,
  });
  yAxisLabel(svg, {
    yAxisLabelText,
    yAxisLabelOffset,
    height,
  });

  // Assuming circle logic here is related to a scatter plot within the same SVG
  const colorScale = scaleLinear()
    .domain([d3.min(data, d => d.Efficiency), d3.max(data, d => d.Efficiency)])
    .range(['#64dfdf', '#7400b8']);

  svg.selectAll('circle')
    .data(data)
    .join('circle')
    .attr('cx', d => xScale(xValue(d)))
    .attr('cy', d => yScale(yValue(d)))
    .attr('r', circleRadius)
    .attr('opacity', circleOpacity)
    .attr('fill', d => colorScale(d.Efficiency));
};
